==> haskell-vty-crossplatform-0.4.0.0-92.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-5HOL6oO5J9X7xNMGrpg1e5
key:                  vty-crossplatform-0.4.0.0-5HOL6oO5J9X7xNMGrpg1e5
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  d370ea72eb33b6dfaa728371d55e5a26
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-5HOL6oO5J9X7xNMGrpg1e5
depends:
    base-4.18.2.1 vty-6.2-E5Gdw2o5UZXGb47CrkUeiY
    vty-unix-0.2.0.0-Fzo1LjDXket6sd4p9HmdsZ

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-crossplatform-0.4.0.0-93-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-8reA8xRGVaiI7RZjI8WpJ7
key:                  vty-crossplatform-0.4.0.0-8reA8xRGVaiI7RZjI8WpJ7
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  cf94e856b7056512a6a0d9e4d7e2b5f5
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-8reA8xRGVaiI7RZjI8WpJ7
depends:
    base-4.18.2.1 vty-6.2-6mvUoRDa0zgJSFHbiRIfKy
    vty-unix-0.2.0.0-31QuceaJ4Yy4i769h1iltI

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
